#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['carbon']

package_data = \
{'': ['*']}

install_requires = \
['pyperclip >=1.8.2', 'python-dotenv >=0.19.0', 'selenium >=3.141.0']

extras_require = \
{'test': ['pytest', 'mypy', 'flake8']}

entry_points = \
{'console_scripts': ['carbon = carbon.__main__:main']}

setup(name='pybites-carbon',
      version='0.3',
      description='A package to automate making beautiful code snippets using Carbon',
      author=None,
      author_email='Bob Belderbos <bob@pybit.es>',
      url=None,
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      entry_points=entry_points,
      python_requires='>=3.7',
     )
